@@ -88,7 +88,7 @@ static void SDLSetWindowIcon(char *basename)
   SDL_SetColorKey(surface, SDL_SRCCOLORKEY,
 		  SDL_MapRGB(surface->format, 0x00, 0x00, 0x00));
 
-  SDL_WM_SetIcon(surface, NULL);
+ // SDL_WM_SetIcon(surface, NULL);
 #endif
 }
 
@@ -113,8 +113,8 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
   static int screen_xy[][2] =
   {
     {  640, 480 },
-    {  800, 600 },
-    { 1024, 768 },
+    {  800, 480 },
+    {  800, 480 },
     {   -1,  -1 }
   };
   SDL_Rect **modes;
@@ -143,8 +143,8 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
 #if 1
   checked_free(video.fullscreen_modes);
 
-  video.fullscreen_modes = NULL;
-  video.fullscreen_mode_current = NULL;
+//  video.fullscreen_modes = NULL;
+//  video.fullscreen_mode_current = NULL;
 #endif
 
   /* get available hardware supported fullscreen modes */
@@ -153,7 +153,9 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
   if (modes == NULL)
   {
     /* no screen modes available => no fullscreen mode support */
-    video.fullscreen_available = FALSE;
+    video.fullscreen_available = TRUE;
+    video.fullscreen_modes[0].width  = 800;
+    video.fullscreen_modes[0].height = 480;;
   }
   else if (modes == (SDL_Rect **)-1)
   {
@@ -161,11 +163,11 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
     video.fullscreen_modes = checked_calloc(2 * sizeof(struct ScreenModeInfo));
 
     /* use native video buffer size for fullscreen mode */
-    video.fullscreen_modes[0].width  = video.width;
-    video.fullscreen_modes[0].height = video.height;
+    video.fullscreen_modes[0].width  = 800;
+    video.fullscreen_modes[0].height = 480;
 
-    video.fullscreen_modes[1].width  = -1;
-    video.fullscreen_modes[1].height = -1;
+    //video.fullscreen_modes[1].width  = -1;
+    //video.fullscreen_modes[1].height = -1;
   }
   else
   {
@@ -207,7 +209,7 @@ void SDLInitVideoBuffer(DrawBuffer **backbuffer, DrawWindow **window,
     if (num_modes == 0)
     {
       /* no appropriate screen modes available => no fullscreen mode support */
-      video.fullscreen_available = FALSE;
+      video.fullscreen_available = TRUE;
     }
   }
 
@@ -272,7 +274,7 @@ boolean SDLSetVideoMode(DrawBuffer **backbuffer, boolean fullscreen)
       Error(ERR_WARN, "SDL_SetVideoMode() failed: %s", SDL_GetError());
 
       /* do not try it again */
-      video.fullscreen_available = FALSE;
+      video.fullscreen_available = TRUE;
 
       success = FALSE;
     }
@@ -306,7 +308,7 @@ boolean SDLSetVideoMode(DrawBuffer **backbuffer, boolean fullscreen)
     {
       (*backbuffer)->surface = new_surface;
 
-      video.fullscreen_enabled = FALSE;
+      video.fullscreen_enabled = TRUE;
 
       success = TRUE;
     }
